@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.10.0";
+our $VERSION = "v6.10.1";
 
 1;
 __END__
@@ -920,9 +920,9 @@ ReactiveX to cater for web developers already familiar with rxjs.
 
 You can start receiving emails for new releases of this module, at L<https://perlmodules.net>.
 
-=head1 CONTRIBUTOR COVENANT CODE OF CONDUCT
+=head1 COMMUNITY CODE OF CONDUCT
 
-The Contributor Covenant Code of Conduct can be found L<here|RxPerl::CodeOfConduct>.
+The Community Code of Conduct can be found L<here|RxPerl::CodeOfConduct>.
 
 =head1 LICENSE
 
